@@ -18,25 +18,35 @@
 #ifndef SRC__RMF_FLEET_ADAPTER__TASKS__CHARGEBATTERY_HPP
 #define SRC__RMF_FLEET_ADAPTER__TASKS__CHARGEBATTERY_HPP
 
-#include "../Task.hpp"
+#include "../LegacyTask.hpp"
 #include "../agv/RobotContext.hpp"
 
 #include <rmf_traffic/agv/Planner.hpp>
 #include <rmf_traffic/Time.hpp>
 
-#include <rmf_task/agv/State.hpp>
+#include <rmf_task/State.hpp>
 #include <rmf_task/requests/ChargeBattery.hpp>
 
+#include <rmf_task_sequence/Phase.hpp>
+#include <rmf_task_sequence/Event.hpp>
+
 namespace rmf_fleet_adapter {
 namespace tasks {
 
 //==============================================================================
-std::shared_ptr<Task> make_charge_battery(
+std::shared_ptr<LegacyTask> make_charge_battery(
   const rmf_task::ConstRequestPtr request,
   const agv::RobotContextPtr& context,
   const rmf_traffic::agv::Plan::Start start,
   const rmf_traffic::Time deployment_time,
-  const rmf_task::agv::State finish_state);
+  const rmf_task::State finish_state);
+
+//==============================================================================
+void add_charge_battery(
+  rmf_task::Activator& task_activator,
+  const rmf_task_sequence::Phase::ConstActivatorPtr& phase_activator,
+  rmf_task_sequence::Event::Initializer& event_initializer,
+  std::function<rmf_traffic::Time()> clock);
 
 } // namespace tasks
 } // namespace rmf_fleet_adapter
